package com.jusfoun.ydylsz.controller;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.service.CrudeoilService;
import com.jusfoun.ydylsz.vo.CrudeoilVO;
import com.jusfoun.ydylsz.vo.out.base.RootResult;
import com.unis.common.utils.JxlModelExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.net.URLEncoder;
import java.text.DecimalFormat;
import java.util.*;

@Log4j
@RestController
@RequestMapping("/crudeoil")
@Api(description="大豆原油登统信息表")
public class CrudeoilController {

	@Autowired
	private CrudeoilService crudeoilService;

	//通风信息获取
		@ApiOperation(value = "大豆原油登统信息表", notes = "参数：仓房编号")
		@GetMapping(value = "/page")
		public RootResult<PageInfo<CrudeoilVO>> page(@RequestParam("cfbm") String cfbm, @RequestParam("pageNo") Integer pageNo, @RequestParam("pageSize") Integer pageSize,@RequestParam(value = "startDate", required = false) String startDate,
													 @RequestParam(value = "endDate", required = false) String endDate){
			RootResult<PageInfo<CrudeoilVO>> r = new RootResult<PageInfo<CrudeoilVO>>();
			try {
				PageInfo<CrudeoilVO> result = crudeoilService.page(cfbm,pageNo,pageSize,startDate,endDate);
				r.setCode(200);
				r.setData(result);
			} catch (Exception e) {
				r.setMsg(e.getMessage());
				e.printStackTrace();
				r.setCode(500);
			}
			return r;
		}

	@ApiOperation(value = "大豆原油-导出", notes = "参数：仓房编号")
	@PostMapping(value = "/impCrudeoil")
	public void impCrudeoil(HttpServletRequest request,
                            HttpServletResponse response,
                            @RequestBody() JSONObject params){
		try {
            String cfbm = params.getString("cfbm");
            String startDate = params.getString("startDate");
            String endDate = params.getString("endDate");
            List<CrudeoilVO> result = crudeoilService.impCrudeoil(cfbm, startDate, endDate);
            List<Map<String, Object>> dataList = new ArrayList<>();
            DecimalFormat decimalFormat = new DecimalFormat("0.00#");
            for (int i = 0; i < result.size(); i++) {
                HashMap<String, Object> item = new HashMap<>();
                CrudeoilVO entity = result.get(i);
                item.put("index", i + 1);
                item.put("clbh", entity.getClbh());
                item.put("ygmc", entity.getYgmc());
                item.put("pzmc", entity.getPzmc());
                item.put("lsxz", entity.getLsxz());
                item.put("scnd", entity.getScnd());
                item.put("rkrq", entity.getRkrq());
                String rksl = decimalFormat.format(entity.getRksl());
                if (rksl.endsWith(".00")) {
                    rksl = rksl.replace(".00", "");
                }
                item.put("rksl", rksl);
                item.put("seqw", entity.getSeqw());
                item.put("sf", entity.getSf());
                item.put("brxzzhl", entity.getBrxzzhl());
                item.put("sj", entity.getSj());
                item.put("gyhz", entity.getGyhz());
                item.put("rjcll", entity.getRjcll());
                dataList.add(item);
            }
            LinkedHashMap<String, String> headMap= new LinkedHashMap<>();
            headMap.put("index", "序号");
            headMap.put("clbh", "车牌号");
            headMap.put("ygmc", "油罐名称");
            headMap.put("pzmc", "粮食品种");
            headMap.put("lsxz", "粮食性质");
            headMap.put("scnd", "生产年度");
            headMap.put("rkrq", "入库时间");
            headMap.put("rksl", "入库数量(kg)");
            headMap.put("seqw", "气味、滋味");
            headMap.put("sf", "水分及挥发物含量%");
            headMap.put("brxzzhl", "不溶性杂质含量%");
            headMap.put("sj", "酸价（KOH）/(mg/g)");
            headMap.put("gyhz", "过氧化值(mmol/kg)");
            headMap.put("rjcll", "溶剂残留量(mg/kg)");

            String fileName= URLEncoder.encode("大豆原油历史登统表.xls", "utf8");
            //sheetName表格名
            String sheetName= "大豆原油历史登统表";
            JxlModelExcelUtil.exportExcel(request, response, fileName, dataList, sheetName, headMap);
		} catch (Exception e) {
            log.error(e.getMessage());
			e.printStackTrace();
		}
	}

	@ApiOperation(value = "大豆原油初始化", notes = "")
	@GetMapping(value = "/imp")
	public RootResult<String> imp(){
		RootResult<String> r = new RootResult<String>();
		try {
			crudeoilService.imp();
			r.setCode(200);
			r.setData("");
		} catch (Exception e) {
			r.setMsg(e.getMessage());
			e.printStackTrace();
			r.setCode(500);
		}
		return r;
	}
}
