package com.jusfoun.ydylsz.controller;

import com.github.pagehelper.util.StringUtil;
import com.jusfoun.ydylsz.service.AlarmService;
import com.jusfoun.ydylsz.service.InventoryAlarmService;
import com.jusfoun.ydylsz.utils.StringUtils;
import com.jusfoun.ydylsz.vo.InventoryAlarmVO;
import com.jusfoun.ydylsz.vo.out.base.RootResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @ClassName InventoryAlarmController
 * @Description 库存超限告警
 * @Author feng.liu@ourwill.com.cn
 * @Date 2023/7/19 17:04
 * @Version 1.0
 **/

@RestController
@RequestMapping("/inventoryAlarm")
@Api(description="库存告警")
public class InventoryAlarmController {

    @Autowired
    private InventoryAlarmService inventoryAlarmService;

    @Autowired
    private AlarmService alarmService;

    @ApiOperation(value = "分页查询库存超限告警", notes = "分页查询库存超限告警")
    @GetMapping(value = "/page")
    public RootResult<Object> selectStorageOverrun(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                   @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                                   @RequestParam(value="ccqy",required = false) String ccqy,
                                                   @RequestParam(value="cfmc",required = false) String cfmc,
                                                   @RequestParam(value="clzt",required = false) Integer clzt,
                                                   @RequestParam(value="clfs",required = false) Integer clfs,
                                                   @RequestParam(value="kqbm",required = false) String kqbm) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(inventoryAlarmService.getPageList(pageNum, pageSize,ccqy,cfmc,clzt,clfs,kqbm));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "报警处理", notes = "报警处理")
    @PostMapping(value = "/deal")
    public RootResult<Object> selectList(@RequestBody InventoryAlarmVO vo){
        RootResult<Object> r = new RootResult<>();
        try {

            if(StringUtils.isEmpty(vo.getId()) && StringUtils.isEmpty(vo.getClrmc()) || StringUtils.isEmpty(vo.getClrbm())){
                r.setCode(200);
                r.setData("处理参数信息为空！");
            }
            inventoryAlarmService.deal(vo);
            r.setCode(200);
            r.setData("处理完成！");
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "定时任务测试", notes = "定时任务测试")
    @GetMapping(value = "/taskTest")
    public RootResult<Object> test() {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            inventoryAlarmService.generateInventoryAlarm();
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "预警告警_设备故障_测温故障", notes = "预警告警_设备故障_测温故障")
    @GetMapping(value = "/storageBadTemperaturepointTest")
    public RootResult<Object> storageBadTemperaturepointTest() {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            alarmService.storageBadTemperaturepoint();
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }
}
