package com.jusfoun.ydylsz.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.service.StorageDewingWarningService;
import com.jusfoun.ydylsz.vo.StorageDewingWarning;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;

@Log4j
@RestController
@RequestMapping(value="/storageDewingWarning")
@Api(value = "结露预警", tags = "结露预警")
public class StorageDewingWarningController {

	@Resource
	private StorageDewingWarningService storageDewingWarningService;

	@ApiOperation(value = "结露预警列表", notes = "支持分页")
    @RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", dataType="int", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", dataType="int", paramType = "query"),
		@ApiImplicitParam(name = "kqmc", value = "承储企业", dataType="string", paramType = "query"),
		@ApiImplicitParam(name = "chmc", value = "仓房名称", dataType="string", paramType = "query"),
		@ApiImplicitParam(name = "bjrq", value = "报警日期", dataType="string", paramType = "query")
	})
	public PageInfo<StorageDewingWarning> getList(Integer pageNum, Integer pageSize, String kqmc, 
			String chmc, String bjrq) {
		PageInfo<StorageDewingWarning> pageInfo = null;
		List<StorageDewingWarning> list = null;
		try {
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			list = storageDewingWarningService.getList(kqmc, chmc, bjrq);
			pageInfo = new PageInfo<StorageDewingWarning>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return pageInfo;
	}

	@ApiOperation(value = "结露预警检测", notes = "")
    @RequestMapping(value = "/getDewingWarning", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	public Map<String, Object> getTemperatureWarning() {
		Map<String, Object> map = new HashMap<>();
		try {
			storageDewingWarningService.getDewingWarning();
			map.put("status", "success");
			map.put("msg", "执行成功!");
		} catch (Exception e) {
			map.put("status", "error");
			map.put("msg", "执行失败!");
			log.error(e.getMessage(), e);
		}
		return map;
	}
}
