package com.jusfoun.ydylsz.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.service.StorageTemperatureWarningService;
import com.jusfoun.ydylsz.vo.StorageTemperatureWarning;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;

@Log4j
@RestController
@RequestMapping(value="/storageTemperatureWarning")
@Api(value = "温度报警", tags = "温度报警")
public class StorageTemperatureWarningController {

	@Resource
	private StorageTemperatureWarningService storageTemperatureWarningService;

	@ApiOperation(value = "温度报警", notes = "支持分页")
    @RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "kqmc", value = "承储企业", paramType = "query"),
		@ApiImplicitParam(name = "chmc", value = "仓房名称", paramType = "query"),
		@ApiImplicitParam(name = "jcsj", value = "监测日期", paramType = "query"),
		@ApiImplicitParam(name = "jblx", value = "警报类型", paramType = "query")
	})
	public PageInfo<StorageTemperatureWarning> getList(Integer pageNum, Integer pageSize, String kqmc, 
			String chmc, String jcsj, String jblx) {
		PageInfo<StorageTemperatureWarning> pageInfo = null;
		List<StorageTemperatureWarning> list = null;
		try {
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			list = storageTemperatureWarningService.getList(kqmc, chmc, jcsj, jblx);
			pageInfo = new PageInfo<StorageTemperatureWarning>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return pageInfo;
	}

	@ApiOperation(value = "温度报警检测", notes = "")
    @RequestMapping(value = "/getTemperatureWarning", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	public Map<String, Object> getTemperatureWarning() {
		Map<String, Object> map = new HashMap<>();
		try {
			storageTemperatureWarningService.getWdDetection();
			map.put("status", "success");
			map.put("msg", "执行成功!");
		} catch (Exception e) {
			map.put("status", "error");
			map.put("msg", "执行失败!");
			log.error(e.getMessage(), e);
		}
		return map;
	}
}
