package com.jusfoun.ydylsz.controller;

import java.util.List;

import com.github.pagehelper.PageHelper;
import com.jusfoun.ydylsz.vo.StorageBadTemperaturePointDTO;
import com.jusfoun.ydylsz.vo.StorageBadTemperaturePointVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.jusfoun.ydylsz.service.TemperatureService;
import com.jusfoun.ydylsz.vo.BadTempVO;
import com.jusfoun.ydylsz.vo.TemperatureVO;
import com.jusfoun.ydylsz.vo.out.base.RootResult;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/temperature")
@Api(tags = "温度信息")
public class TemperatureController {

    @Autowired
    private TemperatureService temperatureServiceBak;

    //通风信息获取
    @ApiOperation(value = "获取仓房温度信息", notes = "参数：仓号或货位号")
    @GetMapping(value = "/list/{cfbm}")
    public RootResult<List<TemperatureVO>> list(@PathVariable("cfbm") String cfbm) {
        RootResult<List<TemperatureVO>> r = new RootResult<List<TemperatureVO>>();
        try {
            List<TemperatureVO> result = temperatureServiceBak.list(cfbm);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "故障设备-测温线缆", notes = "测温线缆故障接口")
    @GetMapping(value = "/badTemperature")
    public RootResult<Object> badTemperature(@RequestParam(value = "roleId", required = false) String roleId) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setCode(200);
            r.setData(temperatureServiceBak.badTemperature(roleId));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "预警告警_设备故障_测温故障", notes = "预警告警_设备故障_测温故障")
    @GetMapping(value = "/storageBadTemperaturepoint/{pageNo}/{pageSize}")
    public RootResult<PageInfo<StorageBadTemperaturePointDTO>> storageBadTemperaturepoint(@PathVariable("pageNo") Integer pageNo,
                                                                                          @PathVariable("pageSize") Integer pageSize,
                                                                                          @RequestParam(value = "kqmc", required = false) String kqmc,
                                                                                          @RequestParam(value = "bjsj", required = false) String bjsj,
                                                                                          @RequestParam(value = "kqdm", required = false) String kqdm) {
        PageHelper.startPage(pageNo, pageSize);
        RootResult<PageInfo<StorageBadTemperaturePointDTO>> r = new RootResult<PageInfo<StorageBadTemperaturePointDTO>>();
        try {
            PageInfo<StorageBadTemperaturePointDTO> result = temperatureServiceBak.storageBadTemperaturepoint(pageNo, pageSize ,kqmc,bjsj,kqdm);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "故障设备-测温线缆 根据组织查询各仓房故障点数量", notes = "测温线缆故障接口")
    @GetMapping(value = "/pageBadTemperatureByOrg")
    public RootResult<Object> pageBadTemperatureByOrg(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                      @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                                      @RequestParam(value = "orgId") String orgId) {
        RootResult<Object> r = new RootResult<>();
        try {
            r.setData(null);
            r.setCode(200);
            r.setData(temperatureServiceBak.pageBadTemperatureByOrg(pageNum, pageSize, orgId));
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "故障设备-摄像头", notes = "摄像头")
    @GetMapping(value = "/badCamera")
    public RootResult<List<BadTempVO>> badCamera() {
        RootResult<List<BadTempVO>> r = new RootResult<List<BadTempVO>>();
        try {
            r.setData(null);
            r.setCode(200);
            r.setData(temperatureServiceBak.badCamera());
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "获取仓房温度信息", notes = "参数：仓号或货位号")
    @GetMapping(value = "/listnew/{cfbm}")
    public RootResult<List<TemperatureVO>> listnew(@PathVariable("cfbm") String cfbm) {
        RootResult<List<TemperatureVO>> r = new RootResult<List<TemperatureVO>>();
        try {
            List<TemperatureVO> result = temperatureServiceBak.listnew(cfbm);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    //通风信息获取
    @ApiOperation(value = "获取仓房温度信息", notes = "参数：仓号或货位号")
    @GetMapping(value = "/page/{cfbm}/{pageNo}/{pageSize}")
    public RootResult<PageInfo<TemperatureVO>> page(@PathVariable("cfbm") String cfbm, @PathVariable("pageNo") Integer pageNo, @PathVariable("pageSize") Integer pageSize) {
        RootResult<PageInfo<TemperatureVO>> r = new RootResult<>();
        try {
            PageInfo<TemperatureVO> result = temperatureServiceBak.page(cfbm, pageNo, pageSize);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }


    //通风信息获取
    @ApiOperation(value = "获取仓房温度信息", notes = "参数：仓号或货位号")
    @GetMapping(value = "/listAll/{cfbm}")
    public RootResult<List<TemperatureVO>> listAll(@PathVariable("cfbm") String cfbm) {
        RootResult<List<TemperatureVO>> r = new RootResult<List<TemperatureVO>>();
        try {
            List<TemperatureVO> result = temperatureServiceBak.listAll(cfbm);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    //通风信息获取
    @ApiOperation(value = "获取仓房五温信息", notes = "参数：仓号或货位号")
    @GetMapping(value = "/chat/{cfbm}")
    public RootResult<List<TemperatureVO>> chat(@PathVariable("cfbm") String cfbm) {
        RootResult<List<TemperatureVO>> r = new RootResult<List<TemperatureVO>>();
        try {
            List<TemperatureVO> result = temperatureServiceBak.chat(cfbm);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "获取仓房五温信息", notes = "参数：仓号或货位号")
    @GetMapping(value = "/cslwData/{id}/{hwbm}")
    public RootResult<TemperatureVO> cslwData(@PathVariable("id") String id, @PathVariable("hwbm") String hwbm) {
        RootResult<TemperatureVO> r = new RootResult<TemperatureVO>();
        try {
            TemperatureVO result = temperatureServiceBak.cslwData(id, hwbm);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }

    @ApiOperation(value = "获取仓房五温信息", notes = "参数：仓号或货位号")
    @GetMapping(value = "/mclwData/{id}/{ch}")
    public RootResult<TemperatureVO> mclwData(@PathVariable("id") String id, @PathVariable("ch") String ch) {
        RootResult<TemperatureVO> r = new RootResult<TemperatureVO>();
        try {
            TemperatureVO result = temperatureServiceBak.mclwData(id, ch);
            r.setData(null);
            r.setCode(200);
            r.setData(result);
        } catch (Exception e) {
            r.setMsg(e.getMessage());
            e.printStackTrace();
            r.setCode(500);
        }
        return r;
    }
}
