package com.jusfoun.ydylsz.service;

import com.alibaba.fastjson.JSONObject;
import com.jusfoun.ydylsz.mapper.HomepageMapper;
import com.jusfoun.ydylsz.mapper.TemperatureMapper;
import com.jusfoun.ydylsz.vo.homepage.InventoryInStock;
import com.jusfoun.ydylsz.vo.homepage.QuantityStatisticVO;
import com.jusfoun.ydylsz.vo.homepage.TodayInventory;
import com.jusfoun.ydylsz.vo.homepage.TodayJob;
import com.unis.common.utils.CurrentUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author by PIG
 * 2023/7/13 16
 */
@Service
public class HomepageService {

    @Autowired
    HomepageMapper homepageMapper;

    @Autowired
    private TemperatureMapper temperatureMapper;

    @Value("#{'${org.shi-liu-qu}'.split(',')}")
    private List<String> city6District;
    @Value("#{'${company.shi-liu-qu}'.split(',')}")
    private List<String> city6Org;

    @Value("#{'${org.all-data}'.split(',')}")
    private List<String> allDataOrg;

    public String getOrgAreaCode() {
        return temperatureMapper.getOrgAreaCode(CurrentUtil.getUserId());
    }

    public JSONObject getHomepageData(Map<String, Object> params) {
        JSONObject resData = new JSONObject();

        String orgId = CurrentUtil.getOrgId();
        boolean isCity6 = city6District.contains(orgId);
        boolean isAllDataOrg = allDataOrg.contains(orgId);
        if (isCity6) {
            params.put("dataLv", "municipal6");
            params.put("orgCodes", city6Org);
        }else if (isAllDataOrg) {
            params.put("dataLv", "allData");
        }else {
            params.put("dataLv", "municipal");
            params.put("orgCode", orgId);
            String areaCode = getOrgAreaCode();
            params.put("areaCode", areaCode);
        }
        QuantityStatisticVO quantityStatisticVO = homepageMapper.getCount(params);
        QuantityStatisticVO outIn = homepageMapper.getOutIn(params);

        List<TodayInventory> todayInventoryList = homepageMapper.listTodayInventoryChange(params);
        BigDecimal inAmount = todayInventoryList.stream().map(TodayInventory::getInAmount).reduce(BigDecimal.ZERO, BigDecimal::add);
        BigDecimal outAmount = todayInventoryList.stream().map(TodayInventory::getOutAmount).reduce(BigDecimal.ZERO, BigDecimal::add);
        quantityStatisticVO.setTodayOut(outAmount);
        quantityStatisticVO.setTodayIn(inAmount);
        resData.put("quantityStatistic", quantityStatisticVO);
        resData.put("todayInventoryList", todayInventoryList);
        List<TodayJob> todayJobList = homepageMapper.listTodayJob(params);
        resData.put("todayJobList", todayJobList);
        List<InventoryInStock> inventoryList = homepageMapper.listInventoryGroupByArea(params);
        List<InventoryInStock> inventoryInStocks = homepageMapper.listInventoryGroupByDepot(params);
        List<InventoryInStock> city6Inventory = inventoryInStocks.stream().filter(i -> city6Org.contains(i.getGroupCode())).collect(Collectors.toList());
        InventoryInStock city6 = new InventoryInStock();
        city6.setGroupName("市内六区");
        city6.setGroupCode("120100");
        city6.setInventoryCount(3);
        BigDecimal provincial = BigDecimal.ZERO;
        BigDecimal municipal = BigDecimal.ZERO;
        for (InventoryInStock item : city6Inventory) {
            provincial = provincial.add(item.getProvincial());
            municipal = municipal.add(item.getMunicipal());
        }
        city6.setMunicipal(municipal);
        city6.setProvincial(provincial);
        city6.setInventoryTotal(provincial.add(municipal));
        inventoryList.add(city6);
        resData.put("mapAreaData", inventoryList);
        return resData;
    }

}
