package com.jusfoun.ydylsz.service;

import com.jusfoun.ydylsz.vo.WarehouseEmptyAlarmVO;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 *
 * @Description：
 * @author：
 * @date: 2020年1月10日 下午2:51:50
 */
@ConditionalOnProperty(prefix = "scheduling", name = "enabled", havingValue = "true")
@Component
@Log4j
public class InventoryAlarmTaskSchedule {


	@Autowired
	private InventoryAlarmService inventoryAlarmService;

	@Autowired
	private AlarmService alarmService;

	//每天定时获取一次
	@Scheduled(cron="0 15 7 * * ?")
	public void updateData() {

		try {
			inventoryAlarmService.generateInventoryAlarm();
			log.info("库存告警：数据定时查询");
		} catch (Exception e) {
			log.info("库存告警：数据定时查询 {}" +e.getMessage());
		}
	}

	//每天定时处理一次
	@Scheduled(cron="0 0 23 * * ?")
	public void systemDealAlarm() {
		try {
			inventoryAlarmService.systemDealAlarm();
			log.info("库存告警定时处理");
		} catch (Exception e) {
			log.info("库存告警定时处理 {}" +e.getMessage());
		}
	}


	//空仓告警数据每天定时获取一次(2023年9月26日停止)
	//@Scheduled(cron="0 30 23 * * ?")
	public void surveyEmptyWarehouseAlarm() {

		try {
			//alarmService.surveyEmptyWarehouseAlarm();
			log.info("空仓告警数据：数据定时查询");
		} catch (Exception e) {
			log.info("空仓告警数据：数据定时查询 {}" +e.getMessage());
		}
	}


	//库存存储超限告警数据每天定时获取一次
	@Scheduled(cron="0 40 23 * * ?")
	public void surveyOverdueAlarm() {

		try {
			alarmService.surveyOverdueAlarm();
			log.info("库存存储超限告警数据：数据定时查询");
		} catch (Exception e) {
			log.info("库存存储超限告警数据：数据定时查询 {}" +e.getMessage());
		}
	}

	@Scheduled(cron="0 0 0/5 * * ?")
	public void surveyDealOverdueAlarm() {

		try {
			alarmService.surveyDealOverdueAlarm();
			log.info("库存存储超限告警数据：数据定时处理");
		} catch (Exception e) {
			log.info("库存存储超限告警数据：数据定时处理 {}" +e.getMessage());
		}
	}


	//预警告警_设备故障_测温故障每天定时获取一次
	@Scheduled(cron="0 0 23 * * ?")
	public void storageBadTemperaturepoint() {

		try {
			alarmService.storageBadTemperaturepoint();
			log.info("预警告警设备故障测温故障数据：数据定时查询");
		} catch (Exception e) {
			log.info("预警告警设备故障测温故障数据：数据定时查询 {}" +e.getMessage());
		}
	}
}
